Function Check-APIVersions {
    param(
    [string] $TemplateFilePath #Location of the template to check
    )

    #Get available resource providers and API versions from Azure Stack 
    #and make result comparable
    $MASResources = Get-AzureRmResourceProvider | Foreach-Object { 
        $Name = $_.ProviderNamespace
        $_.ResourceTypes | 
        Select-object @{name="ResourceProvider";
        expression={$Name + "/" + $_.ResourceTypeName}},Locations,ApiVersions
    }

    #Get content of template and convert to objects
    $template = Convertfrom-JSON (Get-Content $templateFilePath -Raw)

    #Sort available types and discard the "Microsoft.Resources/deployments" type, 
    #as it does not appear in the resrouce provider list
    $templateResources = $template.resources | 
    Where-object { $_.type -ne "Microsoft.Resources/deployments" } | 
    select-object type,apiVersion | Sort type -Unique
    $templateResources | select-object *, @{name="Available";Expression={
       $resource = $_
       if($MASResources | Where-object { 
        $_.ResourceProvider -eq $resource.type -and 
        $_.ApiVersions -contains $resource.apiVersion  }) 
        { $true }
        else { $false }
        }} #end available property
}

#Logon to Azure stack

#Get all used resource types and the status
Check-APIVersions -TemplateFilePath ".\mainTemplate.json"

#Get only the resource types not available
Check-APIVersions -TemplateFilePath ".\mainTemplate.json" | 
Where-Object { $_.Available -eq $false }

#Remember to check any nested templates
Check-APiVersions -TemplateFilePath ".\publicip-existing.json" | 
Where-Object { $_.Available -eq $false }

#or Test all templates in current folder
Get-ChildItem -Path ".\*.json" |
 ForEach-Object { $_.Name; Check-APiVersions -TemplateFilePath $_.FullName | 
 Where-Object { $_.Available -eq $false } }

#or Test all templates in current folder
Get-ChildItem -Path ".\*.json" | ForEach-Object { $_.Name; Check-APiVersions 
-TemplateFilePath $_.FullName | Where-Object { $_.Available -eq $false } }
